ForesterHttpApi

Struct ForesterHttpApi 

pub struct ForesterHttpApi {
    pub base: String,
}
The api to Forester instance of http server It is used to get access to the blackboard and to trace events.

#Example

use forester_http::api::ForesterHttpApi;

async fn main() {
    let api = ForesterHttpApi::new("http://localhost:10000".to_string());
    let  _ = reqwest::get(api.print_trace()).await;
}

Fields

base: String

The base url of the Forester instance. Typically it is http://localhost:10000

Implementations

Source

impl ForesterHttpApi

pub fn trace_event(&self) -> String

creates a new trace event

pub fn print_trace(&self) -> String

prints the trace or if the file is big the tail of the trace (last 100 lines)

pub fn lock(&self, key: String) -> String

lock the key in the blackboard

pub fn unlock(&self, key: String) -> String

unlock the key in the blackboard

pub fn locked(&self, key: String) -> String

check if the key is locked in the blackboard

pub fn contains(&self, key: String) -> String

check if the key is in the blackboard

pub fn take(&self, key: String) -> String

take the key from the blackboard.

pub fn get(&self, key: String) -> String

get the key from the blackboard.

pub fn put(&self, key: String) -> String

put the key to the blackboard.

pub fn new(base: String) -> Self