Module client

Module client 

Structs

CustomEvent
The event that will be recorded to tracer
ForesterHttpClient
the client to the Forester instance of http server It accepts the api and timeout to request
TickError
Error