ForesterHttpClient

Struct ForesterHttpClient 

pub struct ForesterHttpClient { /* private fields */ }
the client to the Forester instance of http server It accepts the api and timeout to request

use forester_http::client::ForesterHttpClient;

async fn main() {
    let client = ForesterHttpClient::new("http://localhost:10000".to_string());
    client.new_trace_event(1, "test".to_string());
}

Implementations

Source

impl ForesterHttpClient

pub fn new(base: String) -> Self

pub async fn new_with(base: String, timeout: Duration) -> Self

pub async fn new_trace_event( &self, tick: usize, text: String, ) -> Result<Response, TickError>

creates a new trace event

pub async fn print_trace(&self) -> Result<Response, TickError>

prints the trace or if the file is big the tail of the trace (last 100 lines)

pub async fn lock(&self, id: String) -> Result<Response, TickError>

lock the key in the blackboard

pub async fn unlock(&self, id: String) -> Result<Response, TickError>

unlock the key in the blackboard

pub async fn locked(&self, id: String) -> Result<Response, TickError>

check if the key is locked in the blackboard

pub async fn contains(&self, id: String) -> Result<Response, TickError>

check if the key is in the blackboard

pub async fn take(&self, id: String) -> Result<Response, TickError>

take the key from the blackboard.

pub async fn get(&self, id: String) -> Result<Response, TickError>

get the key from the blackboard.

pub async fn put(&self, id: String, value: Value) -> Result<Response, TickError>

put the key to the blackboard.