pub enum TickResult {
Success,
Failure(String),
Running,
}Expand description
The result that the node returns It can be Success, Failure or Running The Failure contains the error message The Running means that the node is still running and it will be executed on the next tick
Variants